# Abundance-Occupancy Relationships in Deep Sea Woodfall Communities
# Webb, Barry & McClain

# Code for data manip, analyses and figures by Tom Webb, t.j.webb@sheffield.ac.uk, April 2016
# Run on R 3.2.3, on Mac OSX 10.10.5

# Required datasets (assumed to be in same directory as code): woodfall_species.csv, "masses_update.csv"

# install required packages if necessary
# install.packages(c("dplyr", "reshape2", "ggplot2", "stringr", "quantreg", "faraway", "moments", "readr", "cowplot", "lmtest"))

# Load required packages
library(dplyr)
library(reshape2)
library(ggplot2)
library(stringr)
library(quantreg)
library(faraway)
library(moments)
library(readr)
library(cowplot)
library(lmtest)

# Save / load data as required
# save.image(file = "woodfall_AORs.RData")
# load("woodfall_AORs.RData")

################################################
# Read in woodfall community matrix
wood <- read_csv("woodfall_species.csv")
# reads in data as a species x site (i.e., log) matrix

# examine
names(wood)
str(wood)
dim(wood)
# 32 54

# distribution of wood masses
hist(wood$`Weight (kg)`)
hist(log10(wood$`Weight (kg)`))
# Note gap at 0.5 - smaller than this are 'small' logs, larger are 'large' logs

# Convert to long-thin data frame (each record = one species on one log)
wood_melt <- melt(wood, id.vars = c(
	"Log", "Surface Area (cm2)", "Volume (cm3)",
	"Weight (kg)", "Set", "Size Order"))
names(wood_melt)
# [1] "Log"                "Surface Area (cm2)" "Volume (cm3)"      
# [4] "Weight (kg)"        "Set"                "Size Order"        
# [7] "variable"           "value"
names(wood_melt)[7:8] <- c("species", "abundance")

# Remove zero abundances
wood_melt <- subset(wood_melt, abundance > 0)

# Add density: abundance / wood size
wood_melt$dens <- with(wood_melt, abundance / `Weight (kg)`)
wood_melt$dens[wood_melt$dens ==0] <- NA


#########################################
# Supplementary Materials and figure S1

# Check distribution of abundance, and density, across logs of different sizes

# Minimum abundance by log size
with(wood_melt, tapply(abundance, Log, min))
# min abundance of 1 on every log, so min density declines as 1/log weight

# Quantile regressions showing rather shallow upper bound in abundance, steeper lower bound in density plot
quant_r_ab <- rq(log(abundance) ~ log(`Weight (kg)`), tau = 1:9/10, data = wood_melt)
s_quant_r_ab <- summary(quant_r_ab)
coef(quant_r_ab)[2,]

quant_r_dens <- rq(log(dens) ~ log(`Weight (kg)`), tau = 1:9/10, data = wood_melt)
s_quant_r_dens <- summary(quant_r_dens)
coef(quant_r_dens)[2,]

# simple linear models
summary(lm(log(abundance) ~ log(`Weight (kg)`), data = wood_melt))
summary(lm(log(dens) ~ log(`Weight (kg)`), data = wood_melt))

# Figures showing distribution of abundance and density across logs of different sizes

# First, aggregate data so that point size can reflect number of species at specific abundances per log
data_2 <- aggregate(wood_melt$`Weight (kg)`,
	by = list(x = wood_melt$`Weight (kg)`, y = wood_melt$abundance), length)
names(data_2) <-  c("Weight (kg)", "abundance", "N species")

# Abundance v wood size
(ab_v_wood_size <- ggplot(data_2, aes(x = log(`Weight (kg)`), y = log(abundance))) +
	geom_point(aes(size = `N species`)) +
	geom_quantile(data = wood_melt, quantiles = c(0.1, 0.25, 0.5, 0.75, 0.9)) +
	xlab("log(weight of log)") +
	ylab("log(species abundance)") +
	theme(legend.background = element_rect(fill = F),
		legend.justification = c(0,0),
		legend.position = c(0.04, 0.8))
)

# Do the same for density
data_2 <- aggregate(wood_melt$`Weight (kg)`, by = list(x = wood_melt$`Weight (kg)`, y = wood_melt$dens), length)
names(data_2) <-  c("Weight (kg)", "dens", "N species")

(dens_v_wood_size <- ggplot(data_2, aes(x = log(`Weight (kg)`), y = log(dens))) +
	geom_point(aes(size = `N species`)) +
	geom_quantile(data = wood_melt, quantiles = c(0.1, 0.25, 0.5, 0.75, 0.9)) +
	xlab("log(weight of log)") +
	ylab("log(species density)") +
	theme(legend.position = "none")
)

# Create figure S1
figS1 <- plot_grid(ab_v_wood_size, dens_v_wood_size, labels = c("A", "B"), align = "h")
# PDF version
save_plot("figS1.pdf", figS1, base_height = 4, base_width = 8)
# PNG version
save_plot("figS1.png", figS1, base_height = 4, base_width = 8)


#################################################
# Get body mass data

# Read in mass dataset
woodfall_masses <- read_csv("masses_update.csv")
# Create individual size variable by dividing biomass by abundance
woodfall_masses$ind_mass <- with(woodfall_masses, Weight_mg / Abundance)
# Ensure all species names are space separated
woodfall_masses$Species <- str_replace_all(
	woodfall_masses$Species, "_", " ")
woodfall_masses$Species <- str_replace_all(
	woodfall_masses$Species, "\\.", " ")

# Correct a few species names following guidance from Craig McClain 04/11/15
woodfall_masses$Species[is.na(match(
	woodfall_masses$Species, wood_melt$species))]
# [1] "Poly?"         "Polychaete.15" "X.brooksi"
# Get rid of Poly?
woodfall_masses <- subset(woodfall_masses, Species != "Poly?")
woodfall_masses$Species[
	woodfall_masses$Species == "Polychaete.15"] <- "Polychaete.16"
woodfall_masses$Species[
	woodfall_masses$Species == "X.brooksi"] <- "Xylopholas.crooki"

# Mean mass per species
mass_by_sp <- group_by(woodfall_masses, Species)
# Get total mass and abundance per species
mass_by_sp <- summarise(mass_by_sp,
	total_ab = sum(Abundance),
	total_mass = sum(Weight_mg)
	)
# Get mean individual weight per species
mass_by_sp$mean_wt <- with(mass_by_sp, total_mass / total_ab)


######################################################
# Overall abundance and occupany per species across all logs

# change 0 to NA
wood[, 7:54][wood[, 7:54] == 0] <- NA

# Get occupancy and abundance per species
species_oc <- colSums(!is.na(wood[, 7:54]))
species_ab <- colMeans(wood[, 7:54], na.rm = T)

# data frame for overall species-level numbers
# species = species ID, occ = n. logs occupied, ab = mean abundance per occupied log
# dens = mean density (n / log size) per occupied log
# wood_size = typical log size occupied by a species
# p_occ = proportional occupancy, n_logs = total number of logs (32 for all species here)

overall_do_df <- data.frame(
	species = names(wood)[7:54],
	occ = species_oc,
	ab = species_ab,
	dens = as.vector(tapply(
		wood_melt$dens, wood_melt$species, mean, na.rm = T)),
	p_occ = species_oc/32,
	n_logs = 32
)

##########
# add body size data
overall_do_df$species <- as.vector(overall_do_df$species)
id_sp <- match(overall_do_df$species, mass_by_sp$Species)

overall_do_df$body_size <- mass_by_sp$mean_wt[id_sp]
# add category for small / large
overall_do_df$body_size_cat <- factor(with(overall_do_df,
	cut(body_size, quantile(body_size, c(0:2/2), na.rm = T),
	include.lowest = T, labels = F, na.rm = T)))

##########
# Add approximate higher taxonomic group
# This is simply the first word in the 'species' name
overall_do_df$taxo <- word(overall_do_df$species, 1)
overall_do_df$taxo <- word(overall_do_df$taxo, 1, sep = "([0-9])")

######################################################
# Overall interspecific AOR: Model 1

# Fit model:
fm_aor_all <- glm(p_occ ~ log(ab), data = overall_do_df, family = binomial, weight = n_logs)
summary(fm_aor_all)
confint(fm_aor_all)
# beta = 0.746 (0.658-0.837 CI), se = 0.0456, z = 16.37, P < 0.0001

# check model adequacy using lmtest::lrtest
lrtest(fm_aor_all)
# Significant improvement in likelihood over null model, Chi2 = 340.26, df = 1, P < 0.0001

# Plot overall interspecific AOR
# NB - legend position is optimised for multi-panel fig 1

(p_aor_all <- ggplot(overall_do_df, aes(x = log(ab), y = p_occ)) +
	geom_point(data = subset(overall_do_df, !is.na(body_size)),
		aes(size = log10(body_size)), shape = 21, fill = "black", colour = "black", alpha = 1/2) +
	scale_size_continuous(name = expression(paste(log[10], " body size"))) +
	geom_point(data = subset(overall_do_df, is.na(body_size)),
		size = 2.5, shape = 21, fill = "white") +
	geom_smooth(method = "glm", method.args = list(family = binomial),
		aes(weight = n_logs), colour = "black") +
	xlab("log(mean abundance)") +
	ylab("proportion of logs occupied") +
	theme(
		legend.background = element_rect(fill = F),
		legend.justification = c(0,0),
		legend.position = c(0.015, 0.55)
		)
)

# Overall correlation:
with(overall_do_df, cor.test(log(ab), occ, use = "pairwise.complete"))
# r = 0.745, df = 46, P < 0.0001

######################################################
# Interspecific AOR by size of log - model 2

# Create categorical variable for log size (small v large)
wood_melt$weight_cat <- with(wood_melt, cut(`Weight (kg)`, c(0, 3, 25), labels = c("small", "large")))
wood_melt$weight_cat <- ordered(wood_melt$weight_cat, levels = c("small", "large"))

# Calculate occupancy, abundance and density by weight category
occ_by_wt <- with(wood_melt,
	tapply(!is.na(dens), list(species, weight_cat), sum))
ab_by_wt <- with(wood_melt,
	tapply(abundance, list(species, weight_cat), mean, na.rm = T))
dens_by_wt <- with(wood_melt,
	tapply(dens, list(species, weight_cat), mean, na.rm = T))

# Also get skewnnes in abundance by weight, using moments::skewness
skew_ab_by_wt <- with(wood_melt,
	tapply(abundance, list(species, weight_cat), skewness, na.rm = T))


# Put results into data frame
dens_oc_by_wt <- data.frame(
	species = rep(row.names(occ_by_wt), 2),
	wt = rep(colnames(occ_by_wt), each = nrow(occ_by_wt)),
	occ = as.vector(occ_by_wt),
	ab = as.vector(ab_by_wt),
	dens = as.vector(dens_by_wt),
	skew_ab = as.vector(skew_ab_by_wt)
)

# restrict to species with occ > 0
dens_oc_by_wt <- subset(dens_oc_by_wt, occ > 0)
# tidy workspace
rm(occ_by_wt, ab_by_wt, dens_by_wt, skew_ab_by_wt)
# 13 small logs and 19 large logs
dens_oc_by_wt$p_occ[dens_oc_by_wt$wt == "small"] <- dens_oc_by_wt$occ[dens_oc_by_wt$wt == "small"] / 13
dens_oc_by_wt$p_occ[dens_oc_by_wt$wt == "large"] <- dens_oc_by_wt$occ[dens_oc_by_wt$wt == "large"] / 19
dens_oc_by_wt$n_logs <- ifelse(dens_oc_by_wt$wt == "small", 13, 19)

# Order levels of log size for nicer presentation
dens_oc_by_wt$wt <- ordered(dens_oc_by_wt$wt, levels = c("small", "large"))

# Statistics:
fm_aor_bywt_int <- glm(p_occ ~ log(ab) * wt, family = binomial, data = dens_oc_by_wt, weight = n_logs)
summary(fm_aor_bywt_int)
confint(fm_aor_bywt_int)
# No evidence for significant interaction:
# beta[ab * wt] = -0.015, se = 0.0755, CI -0.165 - 0.132, z = 0.200, P = 0.8420
# Re-fit as additive:
fm_aor_bywt <- glm(p_occ ~ log(ab) + wt - 1, family = binomial, data = dens_oc_by_wt, weight = n_logs)
summary(fm_aor_bywt)
confint(fm_aor_bywt)
# No effect of size of log:
# beta[ab] = 0.712, se = 0.0506, CI 0.616 - 0.814, z = 14.10, P < 0.0001
# beta[wt_small] = -1.685, se = 0.1235, CI -1.931 - -1.447
# beta[wt_large] = -1.513, se = 0.118, CI -1.747 - -1.286
# Contrast [small v large]:
summary(glm(p_occ ~ log(ab) + wt, family = binomial, data = dens_oc_by_wt, weight = n_logs))
# beta = 0.121, se = 0.094, z = 1.286, P = 0.198

# check model adequacy using lmtest::lrtest
lrtest(fm_aor_bywt_int, fm_aor_bywt)
# No change in model fit with interaction (Chi2 = 0.04, df = 1, P = 0.8417)
lrtest(fm_aor_bywt)
# Significant improvement in likelihood over null model, Chi2 = 266.98, df = 1, P < 0.0001


# Plot interspecific AOR by log size
(p_aor_bywt <- 
	ggplot(dens_oc_by_wt, aes(x = log(ab), y = p_occ)) +
	geom_point(aes(fill = wt), shape = 21, colour = "black", size = 3, alpha = 2/3) +
	scale_fill_manual(
		name = "size of log", values = c("darkorange", "steelblue")) +
	scale_colour_manual(
		name = "size of log", values = c("darkorange", "steelblue")) +
	geom_smooth(method = "glm", method.args = list(family = binomial),
		aes(weight = n_logs, group = wt, colour = wt)) +
	xlab("log(mean abundance)") +
	ylab("proportion of logs occupied") +
	theme(
		legend.background = element_rect(fill = F),
		legend.justification = c(0,0),
		legend.position = c(0.02, 0.75)
		)
)

######################################################
# Interspecific AOR with body size - Model 3

fm_aor_all_size_int <- glm(p_occ ~ log(ab) * log(body_size),
	family = binomial,
	data = subset(overall_do_df, !is.na(body_size)),
	weight = n_logs)
summary(fm_aor_all_size_int)
confint(fm_aor_all_size_int)
# No evidence for significant interaction:
# beta[ab * size] = -0.017, se = 0.030, CI -0.075 - 0.041, z = 0.564, P = 0.573
# Re-fit as additive:
fm_aor_all_size <- glm(p_occ ~ log(ab) + log(body_size),
	family = binomial,
	data = subset(overall_do_df, !is.na(body_size)),
	weight = n_logs)
summary(fm_aor_all_size)
confint(fm_aor_all_size)

# beta[abundance] = 0.710 (0.617 - 0.807 CI), se = 0.049, z = 14.63, P < 0.0001
# beta[body size] = 0.078 (0.010 - 0.148 CI), se = 0.035, z = 2.23, P = 0.0255

# So for a given abundance, occupancy is higher in larger species

# check model adequacy using lmtest::lrtest
lrtest(fm_aor_all_size_int, fm_aor_all_size)
# No change in model fit with interaction (Chi2 = 1.22, df = 1, P = 0.2690)
lrtest(fm_aor_all_size)
# Significant improvement in likelihood over null model, Chi2 = 256.48, df = 1, P < 0.0001


# Add fit for given quantiles of body size
body_size_qs <- quantile(overall_do_df$body_size, c(.1, .5, .9), na.rm = T)
# Alternative: use 1, (10, 100), 1000g
range(overall_do_df$ab)

fm_aor_all_size <- glm(p_occ ~ log(ab) * log(body_size),
	family = binomial,
	data = subset(overall_do_df, !is.na(body_size)),
	weight = n_logs)
# Get predicted values for mass of 1 and 1000g
pred_df <- data.frame(
	ab = rep(1:180, 2), body_size = rep(c(1, 1000), each = 180))
size_preds <- predict(
	fm_aor_all_size, newdata = pred_df, type = "response", se = T)
pred_df$fits <- size_preds$fit
pred_df$ymin <- size_preds$fit - 2 * size_preds$se.fit
pred_df$ymax <- size_preds$fit + 2 * size_preds$se.fit

(p_aor_sizemodelfit <- ggplot(pred_df, aes(x = log(ab), y = fits)) +
	scale_colour_manual(
		name = "body size (g)", values = c("darkorange", "steelblue")) +
	geom_ribbon(aes(ymin = ymin, ymax = ymax, group = body_size), alpha = 0.2) +
	geom_line(aes(group = body_size, colour = factor(body_size))) +
	xlab("log(mean abundance)") +
	ylab("proportion of logs occupied") +
	theme(
		legend.background = element_rect(fill = F),
		legend.justification = c(0,0),
		legend.position = c(0.015, 0.8)
		)
)


######################################################
# Interspecific AOR by date of collection 1 - Set level - Model 4a

# Calculate occupancy, abundance and density by Set

occ_by_set <- with(wood_melt,
	tapply(!is.na(dens), list(species, Set), sum))
ab_by_set <- with(wood_melt,
	tapply(abundance, list(species, Set), mean, na.rm = T))
dens_by_set <- with(wood_melt,
	tapply(dens, list(species, Set), mean, na.rm = T))

# Put results into data frame
dens_oc_by_set <- data.frame(
	species = rep(row.names(occ_by_set), 2),
	set = rep(c(1, 2), each = nrow(occ_by_set)),
	occ = as.vector(occ_by_set),
	ab = as.vector(ab_by_set),
	dens = as.vector(dens_by_set)
)

dens_oc_by_set <- subset(dens_oc_by_set, occ > 0)
rm(occ_by_set, ab_by_set, dens_by_set)
dens_oc_by_set$p_occ <- dens_oc_by_set$occ / 16
dens_oc_by_set$n_logs <- 16

# Plot interspecific AOR by set
(p_aor_byset <- 
	ggplot(dens_oc_by_set, aes(x = log(ab), y = p_occ)) +
	geom_point(aes(fill = factor(set)), shape = 21, colour = "black", size = 3, alpha = 2/3) +
	scale_colour_manual(
		name = "Colonisation\nStage", values = c("darkorange", "steelblue")) +
	scale_fill_manual(
		name = "Colonisation\nStage", values = c("darkorange", "steelblue")) +
	geom_smooth(method = "glm", method.args = list(family = binomial),
		aes(weight = n_logs, group = set, colour = factor(set))) +
	xlab("log(mean abundance)") +
	ylab("proportion of logs occupied") +
	theme(
		legend.background = element_rect(fill = F),
		legend.justification = c(0,0),
		legend.position = c(0.02, 0.7)
		)
)

# Model 4a
fm_aor_byset <- glm(p_occ ~ log(ab) * factor(set),
	family = binomial,
	data = dens_oc_by_set, weight = n_logs)
summary(fm_aor_byset)
confint(fm_aor_byset)
# Significant interaction:
# beta[ab * set] = 0.341, se = 0.105, CI 0.136 - 0.548, z = 3.249, P = 0.0012

coef(fm_aor_byset)
# beta[ab_set 1] = 0.528, se = 0.0706, CI = 0.393-0.670
coef(fm_aor_byset)[2] + coef(fm_aor_byset)[4]
coef(fm_aor_byset)[2] + confint(fm_aor_byset)[4,]
# beta[ab_set 2] = 0.869, se = 0.105, CI = 0.664-1.077

# check model adequacy using lmtest::lrtest
lrtest(fm_aor_byset)
# Significant improvement in likelihood over null model, Chi2 = 253.7, df = 1, P < 0.0001


######################################################
# Interspecific AOR by date of collection 2 - species-level - model 4b

# Consider abundance and occupancy for species from CS1&2 separately for both CS1 and CS2
# Add set_ids to dens_oc_by_set
# set_ids identifies which set a species belongs to, 1, 2, or both (1_2):
set_ids <- str_replace(lapply(
	with(dens_oc_by_set, tapply(set, species, unique)), function(x) paste(x[1], x[2], sep = "_")),
	"_NA", "")

set_ids <- data.frame(sp = names(with(dens_oc_by_set, tapply(set, species, unique))),
	set_ids = set_ids)
idx <- match(overall_do_df$species, set_ids$sp)
# add this into the overall_do_df
overall_do_df$set_ids <- as.vector(set_ids$set_ids[idx])
# remove intermediate steps
rm(set_ids, idx)

# Now back into dens_oc_by_set
dens_oc_by_set$set_ids <- overall_do_df$set_ids[match(dens_oc_by_set$species, overall_do_df$species)]
# And combine with set
dens_oc_by_set$set_x_set <- with(dens_oc_by_set, paste(set_ids, set, sep = "-"))


# rename and order factor levels
dens_oc_by_set$set_x_set[dens_oc_by_set$set_x_set == "1_2-1"] <- "CS1&2_1"
dens_oc_by_set$set_x_set[dens_oc_by_set$set_x_set == "1_2-2"] <- "CS1&2_2"
dens_oc_by_set$set_x_set[dens_oc_by_set$set_x_set == "1-1"] <- "CS1"
dens_oc_by_set$set_x_set[dens_oc_by_set$set_x_set == "2-2"] <- "CS2"

dens_oc_by_set$set_x_set <- ordered(dens_oc_by_set$set_x_set, c("CS1&2_1", "CS1&2_2", "CS1", "CS2"))
contrasts(dens_oc_by_set$set_x_set) <- contr.treatment(4)

# MODEL 4b
fm_aor_set_x_set <- glm(p_occ ~ log(ab) * set_x_set,
	family = binomial,
	data = dens_oc_by_set, weight = n_logs)
summary(fm_aor_set_x_set)	

# check model adequacy using lmtest::lrtest
lrtest(fm_aor_set_x_set)
# Significant improvement in likelihood over null model, Chi2 = 290.5, df = 1, P < 0.0001


# check for influential species - espeically one species in set 2 with occ = 0.75 and log(ab) ~3, one in set 1 with occ ~0.2, log(ab) ~ 2.3
fm_inf <- influence.measures(fm_aor_set_x_set)
id_cook <- match("cook.d", colnames(fm_inf$is.inf))
inf_sp <- dens_oc_by_set$species[which(fm_inf$is.inf[, id_cook])]
# Xylophaga concava, Gastropod 10
subset(dens_oc_by_set, species %in% inf_sp)
# get actual Cook's D:
fm_inf$infmat[which(fm_inf$is.inf[, id_cook]), id_cook]
# 7.34, 1.06

(p_aor_by_set_id <- ggplot(dens_oc_by_set, aes(x = log(ab), y = p_occ)) +
	geom_point(aes(colour = set_x_set), size = 3, alpha = 1/2) +
	scale_colour_manual(
		name = "Colonisation Stage",
		values = c("darkorange", "steelblue", "yellow", "darkgreen"),
		labels = c("CS1&2, 1", "CS1&2, 2", "CS1", "CS2")) +
	# all points
#	geom_smooth(
#		method = "glm", method.args = list(family = binomial),
#		aes(weight = n_logs, group = set_x_set, colour = set_x_set)) +
	# excluding influential points
	geom_smooth(data = subset(dens_oc_by_set, !(species %in% inf_sp)),
		method = "glm", method.args = list(family = binomial),
		aes(weight = n_logs, group = set_x_set, colour = set_x_set)) +
	xlab("log(mean abundance)") +
	ylab("proportion of logs occupied") +
	theme(
		legend.background = element_rect(fill = F),
		legend.justification = c(0,0),
		legend.position = c(0.02, 0.82)
		)
)

# Model 4b, excluding influential points
fm_aor_set_x_set <- glm(p_occ ~ log(ab) * set_x_set,
	family = binomial,
	data = subset(dens_oc_by_set, !(species %in% inf_sp)), weight = n_logs)
summary(fm_aor_set_x_set)	
confint(fm_aor_set_x_set)

# check model adequacy using lmtest::lrtest
lrtest(fm_aor_set_x_set)
# Significant improvement in likelihood over null model, Chi2 = 283.3, df = 1, P < 0.0001


# Extract equations for each combination
coef(fm_aor_set_x_set)[1]
confint(fm_aor_set_x_set)[1,]
coef(fm_aor_set_x_set)[2]
confint(fm_aor_set_x_set)[2,]
# CS1&2, set 1 (n = 25): -0.976 (-1.296 - -0.547) + 0.369 (0.216 - 0.529)[log(ab)]
coef(fm_aor_set_x_set)[1] + coef(fm_aor_set_x_set)[3]
coef(fm_aor_set_x_set)[1] + confint(fm_aor_set_x_set)[3,]
coef(fm_aor_set_x_set)[2] + coef(fm_aor_set_x_set)[6]
coef(fm_aor_set_x_set)[2] + confint(fm_aor_set_x_set)[6,]
# CS1&2, set 2 (n = 25): -0.898 (-1.429 - -0.368) + 0.643 (0.410 - 0.882)[log(ab)]
coef(fm_aor_set_x_set)[1] + coef(fm_aor_set_x_set)[4]
coef(fm_aor_set_x_set)[1] + confint(fm_aor_set_x_set)[4,]
coef(fm_aor_set_x_set)[2] + coef(fm_aor_set_x_set)[7]
coef(fm_aor_set_x_set)[2] + confint(fm_aor_set_x_set)[7,]
# CS1 only (n = 8): -2.543 (-3.478 - -1.744) + 2.107 (-1.076 - 4.886)[log(ab)]
coef(fm_aor_set_x_set)[1] + coef(fm_aor_set_x_set)[5]
coef(fm_aor_set_x_set)[1] + confint(fm_aor_set_x_set)[5,]
coef(fm_aor_set_x_set)[2] + coef(fm_aor_set_x_set)[8]
coef(fm_aor_set_x_set)[2] + confint(fm_aor_set_x_set)[8,]
# CS2 only (n = 15): -2.092 (-2.693 - -1.517) + 1.761 (0.912 - 2.629)[log(ab)]


######################################################
# Intraspecific trajectories and differences between sets - model 5

# Species occurring in both sets have substantially higher dens and occ in either set than do species occurring in only that set - i.e. commonness typically persists through time 

with(dens_oc_by_set, tapply(log(ab), list(set, set_ids), mean))
with(dens_oc_by_set, tapply(p_occ, list(set, set_ids), mean))

# Plot abundance within each CS by CS membership (i.e. CS1, CS1&2, CS2)
(ab_in_set_by_set <- ggplot(dens_oc_by_set, aes(y = log(ab), x = factor(set), fill = set_ids, dodge = set_ids)) +
	geom_boxplot(alpha = 2/3) +
	scale_fill_manual(name = "CS occurrence", values = c("darkorange", "steelblue", "darkgreen"),
		labels = c("CS1", "CS1&2", "CS2")) +
	ylab("log(mean abundance)") +
	xlab("Colonisation Stage") +
	theme(
		legend.background = element_rect(fill = F),
		legend.justification = c(0,0),
		legend.position = c(0.02, 0.7)
		)
)

# Plot occupancy within each CS by CS membership (i.e. CS1, CS1&2, CS2)
(oc_in_set_by_set <- ggplot(dens_oc_by_set, aes(y = p_occ, x = factor(set), fill = set_ids, dodge = set_ids)) +
	geom_boxplot(alpha = 2/3) +
	scale_fill_manual(name = "CS occurrence", values = c("darkorange", "steelblue", "darkgreen")) +
	ylab("logs occupied") +
	xlab("Colonisation Stage") +
	theme(legend.position = "none")
#		legend.background = element_rect(fill = F),
#		legend.justification = c(0,0),
#		legend.position = c(0.02, 0.8)
#		)
)

# create n_sets variable for number of sets occupied
dens_oc_by_set$n_sets <- 1
dens_oc_by_set$n_sets[dens_oc_by_set$set_ids == "1_2"] <- 2
dens_oc_by_set$n_sets <- factor(dens_oc_by_set$n_sets)
dens_oc_by_set$set <- factor(dens_oc_by_set$set)


# Occupancy by number of sets and set id:
fm_occ_by_set_id <- glm(p_occ ~ n_sets * set - 1,
	data = dens_oc_by_set, family = binomial, weights = n_logs)
summary(fm_occ_by_set_id)
# additive:
summary(glm(p_occ ~ n_sets + set, data = dens_oc_by_set,
	family = binomial, weights = n_logs))
predict(fm_occ_by_set_id, newdata = data.frame(n_sets = factor(c(1,2,1,2)), set = factor(c(1,1,2,2)),
	n_logs = 16), type = "response")

summary(fm_occ_by_set_id)
confint(fm_occ_by_set_id)

# check model adequacy using lmtest::lrtest
lrtest(fm_occ_by_set_id)
# Significant improvement in likelihood over null model, Chi2 = 160.9, df = 1, P < 0.0001

# Coefficients, link scale:
# 1 set, set 1:
-2.1800
# CI
c(-2.8023375, -1.64577932)
# 2 sts, set 1:
-0.1704
# CI
c(-0.3678288, 0.02590727)
# 1 set, set 2:
(-2.1800 + 0.7674)
# CI
c((-2.1800 + 0.1377331), (-2.1800  + 1.45983068))
# 2 sts, set 2:
(-0.1704 + 0.7674 - 0.2743)
# CI
c((-0.1704 + 0.7674 - 1.0181449), (-0.1704 + 0.7674 + 0.41665233))

# Response scale
# 1 set, set 1:
ilogit(-2.1800)
# CI
ilogit(c(-2.8023375, -1.64577932))
# 0.10 (0.057, 0.162)
# 2 sts, set 1:
ilogit(-0.1704)
# CI
ilogit(c(-0.3678288, 0.02590727))
# 0.46 (0.409, 0.506)
# 1 set, set 2:
ilogit((-2.1800 + 0.7674))
# CI
ilogit(c((-2.1800 + 0.1377331), (-2.1800  + 1.45983068)))
# 0.20 (0.115, 0.327)
# 2 sts, set 2:
ilogit((-0.1704 + 0.7674 - 0.2743))
# CI
ilogit(c((-0.1704 + 0.7674 - 1.0181449), (-0.1704 + 0.7674 + 0.41665233)))
# 0.58 (0.396, 0.734)

# abundance by number of sets and set id
fm_ab_by_set_id <- lm(log(ab) ~ n_sets * set - 1, data = dens_oc_by_set)
# additive
summary(lm(log(ab) ~ n_sets + set, data = dens_oc_by_set))

summary(fm_ab_by_set_id)
confint(fm_ab_by_set_id)

# check model adequacy using lmtest::lrtest
lrtest(fm_ab_by_set_id)
# Significant improvement in likelihood over null model, Chi2 = 24.04, df = 1, P < 0.0001


# Coefficients:
# 1 set, set 1:
0.36
# CI
c(-0.551, 1.263)
# 2 sts, set 1:
2.01
# CI
c(1.493, 2.519)
# 1 set, set 2:
(0.35578 - 0.01207)
# 0.34
# CI
c((0.35578 -1.1351476), (0.35578  + 1.111006))
# -0.779, 1.467
# 2 sts, set 2:
(2.00580 -0.01207 + 0.05671)
# 2.05
# CI
c((2.00580 -0.01207 - 1.2803608), (2.00580 -0.01207 + 1.393781))
# 0.713, 3.388

# Look at changes in density v changes in occupancy

# First, limit to species occurring in both sets
do_both_sets <- subset(dens_oc_by_set, set_ids == "1_2")
# Cast the data to get a column of occ for each species in each set
d_occ <- dcast(data = do_both_sets, species ~ set, value.var = "p_occ")
# extract species ID
d_species <- as.vector(d_occ$species)
# difference in occupancy from set 1 to set to is then:
d_occ <- d_occ[,3] - d_occ[,2]
# Same for dens and abundance
d_dens <- dcast(data = do_both_sets, species ~ set, value.var = "dens")
d_dens <- log(d_dens[,3]) - log(d_dens[,2])
d_ab <- dcast(data = do_both_sets, species ~ set, value.var = "ab")
d_ab <- log(d_ab[,3]) - log(d_ab[,2])

# Put this into data frame
delta_do <- data.frame(species = d_species, d_occ = d_occ, d_dens = d_dens, d_ab = d_ab)

# add categories for changes in ab and oc - -1 = decrease, 0 = no change, +1 = increase
delta_do$d_occ_cat <- 0
delta_do$d_occ_cat[delta_do$d_occ < 0] <- -1
delta_do$d_occ_cat[delta_do$d_occ > 0] <- 1

delta_do$d_dens_cat <- 0
delta_do$d_dens_cat[delta_do$d_dens < 0] <- -1
delta_do$d_dens_cat[delta_do$d_dens > 0] <- 1

delta_do$d_ab_cat <- 0
delta_do$d_ab_cat[delta_do$d_ab < 0] <- -1
delta_do$d_ab_cat[delta_do$d_ab > 0] <- 1

# remove unwanted objects
rm(do_both_sets, d_occ, d_species, d_dens, d_ab)

# get frequencies within each category (decline-decline, decline-increase, etc.)
with(delta_do, table(d_occ_cat, d_ab_cat))
# 11 species (44%) increase in both; 3 species decrease in both (so 56% are in expected AOR direction); 1 species increased in ab, decreased in occ; 6 species decreased in ab, increased in occ; 2 species decreased in ab with no change in occ and 1 species decreased in occ with no change in ab.

with(delta_do, cor.test(d_occ, d_ab))
# r = 0.64, df = 23, P = 0.0006

# plot delta occ v delta ab
(d_occ_v_d_ab <- ggplot(delta_do, aes(x = d_ab, y = d_occ)) +
	coord_cartesian(xlim = c(-4.15, 2.15), ylim = c(-0.4, 0.6)) +
	annotate("rect", xmin = -4.15, xmax = 0, ymin = -0.4, ymax = 0, fill = "darkorange", alpha = 1/3) +
	annotate("rect", xmin = 0, xmax = 2.15, ymin = 0, ymax = 0.6, fill = "darkorange", alpha = 1/3) +
	geom_point(colour = "steelblue", size = 3) +
	xlab("change in mean abundance") +
	ylab("change in occupancy")
)

# Intraspecific trajectories onto interspecific plot
(p_aor_byset_intra <- ggplot(subset(dens_oc_by_set, set_ids == "1_2"), aes(x = log(ab), y = p_occ)) +
	geom_path(aes(group = species),
		arrow = arrow(length = unit(0.1, "inches"), type = "closed"), colour = "steelblue") +
	xlab("log(mean abundance)") +
	ylab("proportion of logs occupied") #+
)

# Correlates of changes in occ and abundance
# Add body size to delta_do
idx <- match(delta_do$species, overall_do_df$species)
delta_do$body_size <- overall_do_df$body_size[idx]

# Add abundance and occupancy in CS1
cs1_df <- subset(dens_oc_by_set, set == 1)
idx <- match(delta_do$species, cs1_df$species)
delta_do$ab_cs1 <- cs1_df$ab[idx]
delta_do$p_occ_cs1 <- cs1_df$p_occ[idx]
rm(cs1_df)

# Add 'typical' log size occupied by species in CS1 - the mean of the sizes of logs they occupied weighted by their abundance on each log
# Get CS1 raw data
wood_CS1 <- subset(wood_melt, Set == 1)
# Subset to species present in delta_do dataset
wood_CS1 <- wood_CS1[wood_CS1$species %in% delta_do$species, ]
wood_CS1$species <- as.vector(wood_CS1$species)
delta_do$logsize_cs1 <- as.vector(with(wood_CS1,
	tapply(seq(along = `Weight (kg)`), species, function(
		i, x = `Weight (kg)`, w = abundance) weighted.mean(x[i], w[i]))
	))
rm(wood_CS1)

## Model 6a (new for revision)
# model change in occupancy as a function of change in abundance, body size, abundance in CS1 and occupancy in CS1, and typical size of log occupied in CS1
fm_d_occ_v_traits <- lm(d_occ ~ d_ab + log(body_size) + log(ab_cs1) + p_occ_cs1 + logsize_cs1, data = delta_do)
summary(fm_d_occ_v_traits)
confint(fm_d_occ_v_traits)


# do same without body size to include all species - model 6b
fm_d_occ_v_traits2 <- lm(d_occ ~ d_ab + log(ab_cs1) + p_occ_cs1 + logsize_cs1, data = delta_do)
summary(fm_d_occ_v_traits2)
confint(fm_d_occ_v_traits2)

# only d_ab significant, though size of log close (P = 0.0726)

###################################################

# Distribution of body sizes between CS1 and CS2
do_by_set_mass <- left_join(dens_oc_by_set, mass_by_sp, by = c("species" = "Species"))
ggplot(do_by_set_mass, aes(x = factor(set), y = log10(mean_wt))) +
	geom_boxplot()

summary(lm(log10(mean_wt) ~ factor(set), data = do_by_set_mass))


###################################################

# Figure S1: Layout of logs

# Extract info on logs from wood data frame
log_info <- dplyr::select(wood, Log, `Weight (kg)`, Set)
# For convenience: a numerical log_id
log_info$log_id <- as.numeric(str_replace(log_info$Log, "L", ""))
# And a text CS
log_info$cs <- with(log_info, paste0("CS", Set))

# Enter experimental layout info for each log
log_info$rowid <- NA
log_info$rowid[log_info$log_id %in% c(27, 6, 35, 13, 19, 22, 21, 5)] <- 15
log_info$rowid[log_info$log_id %in% c(26, 31, 28, 15, 17, 16, 1, 24)] <- 10
log_info$rowid[log_info$log_id %in% c(18, 30, 3, 7, 10, 32, 12, 11)] <- 5
log_info$rowid[log_info$log_id %in% c(20, 23, 8, 29, 4, 2, 9, 14)] <- 0

log_info$colid <- NA
log_info$colid[log_info$log_id %in% c(27, 26, 18, 20)] <- 1
log_info$colid[log_info$log_id %in% c(6, 31, 30, 23)] <- 2
log_info$colid[log_info$log_id %in% c(35, 28, 3, 8)] <- 3
log_info$colid[log_info$log_id %in% c(13, 15, 7, 29)] <- 4
log_info$colid[log_info$log_id %in% c(19, 17, 10, 4)] <- 5
log_info$colid[log_info$log_id %in% c(22, 16, 32, 2)] <- 6
log_info$colid[log_info$log_id %in% c(21, 1, 12, 9)] <- 7
log_info$colid[log_info$log_id %in% c(5, 24, 11, 14)] <- 8

log_info <- arrange(log_info, rowid, colid)

# get x values reflecting equal spacing (4m) between logs of different sizes
log_info$xval <- 0

for(i in 1:4){
	for(j in 2:8){
		k <- (i-1)*8 + j
		log_info$xval[k] <- 
			log_info$xval[k - 1] + 
			0.5*log_info$`Weight (kg)`[k - 1] +
			0.5*log_info$`Weight (kg)`[k] +
			4		
	}	
}

# Plot the experimental layout:
(log_layout <- ggplot(log_info) +
	geom_rect(aes(
		xmax = xval + 0.5*`Weight (kg)`, xmin = xval - 0.5*`Weight (kg)`,
		ymax = rowid + 0.5, ymin = rowid - 0.5,
		fill = cs)) +
	scale_fill_manual(values = c("darkorange", "steelblue")) +
	geom_text(aes(x = xval, y = rowid + 1.1,
		label = paste0(Log, "\n", `Weight (kg)`, "kg")), size = 3) +
	annotate("text", x = 76, y = 12.5, label = "10m", size = 4) +
	annotate("text", x = 2.45, y = 14, label = "4m", size = 4) +
	annotate("segment", x = 73, xend = 73, y = 14.4, yend = 10.6,
		arrow = arrow(ends = "both", length = unit(0.15, "cm")), size = 0.25) +
	annotate("segment", x = 0.45, xend = 4.45, y = 14.4, yend = 14.4,
		arrow = arrow(ends = "both", length = unit(0.15, "cm")), size = 0.25) +
	theme_void() +
	theme(legend.position = "none")

)

# Check distribution of log sizes between CS1 and 2:
ggplot(log_info, aes(x = cs, y = log10(`Weight (kg)`))) +
	geom_violin(aes(fill = cs), adjust = 0.1) +
	scale_fill_manual(values = c("darkorange", "steelblue")) +
	theme(legend.position = "none")
# Compare number of big and small logs (defined as > or < 10^0.5kg):
log_info$logsize_cat <- ifelse(log_info$`Weight (kg)` < 10^0.5, "small", "big")
with(log_info, table(logsize_cat, cs))


###################################################
# Assembly of final figures

# Figure 1
dev.new(width = 8, height = 8)
(fig1 <- plot_grid(p_aor_all, p_aor_bywt, p_aor_sizemodelfit, p_aor_byset, labels = LETTERS[1:4],
	align = "h"))
save_plot("fig1_R1.pdf", fig1, base_height = 8, base_width = 8)
save_plot("fig1_R1.png", fig1, base_height = 8, base_width = 8)

# Figure 2
dev.new(width = 12, height = 8)
(fig2 <- ggdraw() +
	draw_plot(p_aor_by_set_id, x = 0, y = 0, width = 0.62, height = 1) +
	draw_plot(ab_in_set_by_set, x = 2/3, y = 0.5, width = 1/3, height = 0.5) +
	draw_plot(oc_in_set_by_set, x = .645, y = 0, width = 1/3, height = 0.5) +
	draw_plot_label(LETTERS[1:3], x = c(0, 2/3, 2/3), y = c(1, 1, 0.53))
)
save_plot("fig2_R1.pdf", fig2, base_height = 8, base_width = 12)
save_plot("fig2_R1.png", fig2, base_height = 8, base_width = 12)

# Figure 3
dev.new(width = 8, height = 4)
(fig3 <- plot_grid(d_occ_v_d_ab, p_aor_byset_intra, labels = c("A", "B"), align = "h"))
save_plot("fig3.pdf", fig3, base_height = 4, base_width = 8)
save_plot("fig3.png", fig3, base_height = 4, base_width = 8)

# Figure S1
ggsave("figS1_R1.pdf", log_layout, width = 8, height = 5)
ggsave("figS1_R1.png", log_layout, width = 8, height = 5)

